# Changelog

## 0.1.0 (2026-03-18)

Full Changelog: [v0.0.1...v0.1.0](https://github.com/VAT-Sense/vatsense-python/compare/v0.0.1...v0.1.0)

### Features

* **api:** api update ([25b4c32](https://github.com/VAT-Sense/vatsense-python/commit/25b4c32c42aee862ace266abe50365349aceb431))


### Chores

* update SDK settings ([5f02a50](https://github.com/VAT-Sense/vatsense-python/commit/5f02a5091af62c43c861061aa66a706588a24425))
* update SDK settings ([cca1b6b](https://github.com/VAT-Sense/vatsense-python/commit/cca1b6be03b5466f0b6170fdf0884577d3c574cd))
* update SDK settings ([a72583d](https://github.com/VAT-Sense/vatsense-python/commit/a72583dbaca3469d6f8c3281dbca3a4c9256ea28))
